import { Construct } from "constructs";
import { AddStageOpts, CodePipeline, IFileSetProducer, StageDeployment, Wave, WaveOptions } from "aws-cdk-lib/pipelines";
import { ComputeType, IBuildImage } from "aws-cdk-lib/aws-codebuild";
import { PipelineNotificationRule } from "./pipeline-notification-rule";
import { Stage } from "aws-cdk-lib";
import { NodePackageManager } from "./enums";
import { PolicyStatement } from "aws-cdk-lib/aws-iam";
import { ISlackChannelConfiguration } from "aws-cdk-lib/aws-chatbot";
import { ITopic } from "aws-cdk-lib/aws-sns";
export declare enum NodeVersion {
    NODE_16 = "16",
    NODE_18 = "18"
}
/**
 * Properties for CdkPipeline
 */
export interface CdkPipelineProps {
    /**
     * By default, CDK will name the pipeline. Set this to override the name.
     */
    readonly pipelineName?: string;
    /**
     * By default, CDK will create KMS keys for cross account deployments. This
     * can be costly if you have a large number of pipelines. This property
     * allows a common key to be shared across pipelines.
     */
    readonly keyArn: string;
    /**
     * List of account IDs this pipeline will deploy into.
     */
    readonly accountIds?: string[];
    /**
     * Arn of the CodeStar connection used to access the source code repository. If not set, this
     * construct assumes the repository is in AWS CodeCommit.
     */
    readonly connectionArn?: string;
    /**
     * Source code repository.
     */
    readonly repository: string;
    /**
     * Branch to use inside the source code repository.
     */
    readonly branch: string;
    /**
     * Enable or disable self-mutation. Useful for cdk pipeline development.
     *
     * @default true
     */
    readonly selfMutation?: boolean;
    /**
     * Enable docker for the 'synth' step.
     *
     * @default true
     */
    readonly dockerEnabledForSynth?: boolean;
    /**
     * Enable docker for the self-mutate step.
     *
     * @default true
     */
    readonly dockerEnabledForSelfMutation?: boolean;
    /**
     * Type of compute to use for this build.
     *
     * @default ComputeType.SMALL
     */
    readonly computeType?: ComputeType;
    /**
     * The image to use for builds. Default is LinuxBuildImage.AMAZON_LINUX_2_5.
     */
    readonly buildImage?: IBuildImage;
    /**
     * The ARN of the Slack channel configuration to use for notifications. Mutually exclusive with slackChannelConfiguration.
     */
    readonly slackChannelConfigurationArn?: string;
    /**
     * The Slack channel configuration to use for notifications. Mutually exclusive with slackChannelConfigurationArn.
     */
    readonly slackChannelConfiguration?: ISlackChannelConfiguration;
    /**
     * The SNS topic to use for notifications. Mutually exclusive with notificationTopic.
     */
    readonly notificationTopicArn?: string;
    /**
     * The SNS topic to use for notifications. Mutually exclusive with notificationTopicArn.
     */
    readonly notificationTopic?: ITopic;
    /**
     * The list of notification events to receive. Default is PipelineNotificationRule.PIPELINE_EXECUTION_EVENTS.
     * @default PipelineNotificationRule.PIPELINE_EXECUTION_EVENTS
     * @see https://docs.aws.amazon.com/dtconsole/latest/userguide/concepts.html#events-ref-pipeline
     */
    readonly notificationEvents?: string[];
    /**
     * Additional FileSets to put in other directories
     */
    readonly additionalInputs?: Record<string, IFileSetProducer>;
    /**
     * Overrides default commands.
     */
    readonly commands?: string[];
    /**
     * Public assets in multiple CodeBuild projects. Default is false.
     */
    readonly publishAssetsInParallel?: boolean;
    /**
     * Package manager to use when executing CDK.
     *
     * @default NodePackageManager.PNPM
     */
    readonly packageManager?: NodePackageManager;
    /**
     * The directory the CDK project is located in the repo.
     *
     * @default - "."
     */
    readonly cdkDirectory?: string;
    /**
     * Policy statements to add to the role used by synth.
     */
    readonly rolePolicy?: PolicyStatement[];
    /**
     * Grants read access to the provided AWS CodeArtifact domains.
     */
    readonly codeArtifactDomains?: string[];
    /**
     * Grants read access to the provided AWS CodeArtifact repositories.
     */
    readonly codeArtifactRepositories?: string[];
    /**
     * The version of Node to use in the pipeline. Default is NODE_18
     */
    readonly nodeVersion?: NodeVersion | string;
}
/**
 * An abstraction to ease CDK pipeline creation and configuration.
 */
export declare class CdkPipeline extends Construct {
    readonly pipeline: CodePipeline;
    readonly pipelineNotificationRule?: PipelineNotificationRule;
    constructor(scope: Construct, id: string, props: CdkPipelineProps);
    addStage(stage: Stage, options?: AddStageOpts): StageDeployment;
    addWave(id: string, options?: WaveOptions): Wave;
}
